@@ -72,3 +72,38 @@ from .dom import (
     wrapContents,
 )
 from .serializer import Serializer
+from .parser import test
+from .parser import (
+    Comment,
+    EndTag,
+    Failure,
+    isASCII,
+    isASCIIAlpha,
+    isASCIIAlphanum,
+    isASCIILowerAlpha,
+    isASCIIUpperAlpha,
+    isAttrNameChar,
+    isControl,
+    isDigit,
+    isHexDigit,
+    isNoncharacter,
+    isTagnameChar,
+    isWhitespace,
+    parseAttribute,
+    parseCharRef,
+    parseComment,
+    parseDoctype,
+    parseEndTag,
+    ParseFailure,
+    parseQuotedAttrValue,
+    parseScriptToEnd,
+    parseStartTag,
+    parseStyleToEnd,
+    parseTagName,
+    parseUnquotedAttrValue,
+    parseWhitespace,
+    parseXmpToEnd,
+    Result,
+    StartTag,
+    Stream,
+)
